==> vtk6-6.3.0-10-aarch64.pkg.tar.xz: vtk/vtkGeoCamera.java <==
// java wrapper for vtkGeoCamera object
//

package vtk;
import vtk.*;

public class vtkGeoCamera extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native double[] GetPosition_2();
  public double[] GetPosition()
    { return GetPosition_2(); }

  private native void SetLongitude_3(double id0);
  public void SetLongitude(double id0)
    { SetLongitude_3(id0); }

  private native double GetLongitude_4();
  public double GetLongitude()
    { return GetLongitude_4(); }

  private native void SetLatitude_5(double id0);
  public void SetLatitude(double id0)
    { SetLatitude_5(id0); }

  private native double GetLatitude_6();
  public double GetLatitude()
    { return GetLatitude_6(); }

  private native void SetDistance_7(double id0);
  public void SetDistance(double id0)
    { SetDistance_7(id0); }

  private native double GetDistance_8();
  public double GetDistance()
    { return GetDistance_8(); }

  private native void SetHeading_9(double id0);
  public void SetHeading(double id0)
    { SetHeading_9(id0); }

  private native double GetHeading_10();
  public double GetHeading()
    { return GetHeading_10(); }

  private native void SetTilt_11(double id0);
  public void SetTilt(double id0)
    { SetTilt_11(id0); }

  private native double GetTilt_12();
  public double GetTilt()
    { return GetTilt_12(); }

  private native long GetVTKCamera_13();
  public vtkCamera GetVTKCamera() {
    long temp = GetVTKCamera_13();

    if (temp == 0) return null;
    return (vtkCamera)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void InitializeNodeAnalysis_14(int id0[]);
  public void InitializeNodeAnalysis(int id0[])
    { InitializeNodeAnalysis_14(id0); }

  private native double GetNodeCoverage_15(vtkGeoTerrainNode id0);
  public double GetNodeCoverage(vtkGeoTerrainNode id0)
    { return GetNodeCoverage_15(id0); }

  private native boolean GetLockHeading_16();
  public boolean GetLockHeading()
    { return GetLockHeading_16(); }

  private native void SetLockHeading_17(boolean id0);
  public void SetLockHeading(boolean id0)
    { SetLockHeading_17(id0); }

  private native void LockHeadingOn_18();
  public void LockHeadingOn()
    { LockHeadingOn_18(); }

  private native void LockHeadingOff_19();
  public void LockHeadingOff()
    { LockHeadingOff_19(); }

  private native void SetOriginLatitude_20(double id0);
  public void SetOriginLatitude(double id0)
    { SetOriginLatitude_20(id0); }

  private native double GetOriginLatitude_21();
  public double GetOriginLatitude()
    { return GetOriginLatitude_21(); }

  private native void SetOriginLongitude_22(double id0);
  public void SetOriginLongitude(double id0)
    { SetOriginLongitude_22(id0); }

  private native double GetOriginLongitude_23();
  public double GetOriginLongitude()
    { return GetOriginLongitude_23(); }

  private native double[] GetOrigin_24();
  public double[] GetOrigin()
    { return GetOrigin_24(); }

  private native void SetOrigin_25(double id0,double id1,double id2);
  public void SetOrigin(double id0,double id1,double id2)
    { SetOrigin_25(id0,id1,id2); }

  public vtkGeoCamera() { super(); }

  public vtkGeoCamera(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-aarch64.pkg.tar.xz: vtk/vtkGeoCamera.java <==
// java wrapper for vtkGeoCamera object
//

package vtk;
import vtk.*;

public class vtkGeoCamera extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native double[] GetPosition_2();
  public double[] GetPosition()
    { return GetPosition_2(); }

  private native void SetLongitude_3(double id0);
  public void SetLongitude(double id0)
    { SetLongitude_3(id0); }

  private native double GetLongitude_4();
  public double GetLongitude()
    { return GetLongitude_4(); }

  private native void SetLatitude_5(double id0);
  public void SetLatitude(double id0)
    { SetLatitude_5(id0); }

  private native double GetLatitude_6();
  public double GetLatitude()
    { return GetLatitude_6(); }

  private native void SetDistance_7(double id0);
  public void SetDistance(double id0)
    { SetDistance_7(id0); }

  private native double GetDistance_8();
  public double GetDistance()
    { return GetDistance_8(); }

  private native void SetHeading_9(double id0);
  public void SetHeading(double id0)
    { SetHeading_9(id0); }

  private native double GetHeading_10();
  public double GetHeading()
    { return GetHeading_10(); }

  private native void SetTilt_11(double id0);
  public void SetTilt(double id0)
    { SetTilt_11(id0); }

  private native double GetTilt_12();
  public double GetTilt()
    { return GetTilt_12(); }

  private native long GetVTKCamera_13();
  public vtkCamera GetVTKCamera() {
    long temp = GetVTKCamera_13();

    if (temp == 0) return null;
    return (vtkCamera)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void InitializeNodeAnalysis_14(int id0[]);
  public void InitializeNodeAnalysis(int id0[])
    { InitializeNodeAnalysis_14(id0); }

  private native double GetNodeCoverage_15(vtkGeoTerrainNode id0);
  public double GetNodeCoverage(vtkGeoTerrainNode id0)
    { return GetNodeCoverage_15(id0); }

  private native boolean GetLockHeading_16();
  public boolean GetLockHeading()
    { return GetLockHeading_16(); }

  private native void SetLockHeading_17(boolean id0);
  public void SetLockHeading(boolean id0)
    { SetLockHeading_17(id0); }

  private native void LockHeadingOn_18();
  public void LockHeadingOn()
    { LockHeadingOn_18(); }

  private native void LockHeadingOff_19();
  public void LockHeadingOff()
    { LockHeadingOff_19(); }

  private native void SetOriginLatitude_20(double id0);
  public void SetOriginLatitude(double id0)
    { SetOriginLatitude_20(id0); }

  private native double GetOriginLatitude_21();
  public double GetOriginLatitude()
    { return GetOriginLatitude_21(); }

  private native void SetOriginLongitude_22(double id0);
  public void SetOriginLongitude(double id0)
    { SetOriginLongitude_22(id0); }

  private native double GetOriginLongitude_23();
  public double GetOriginLongitude()
    { return GetOriginLongitude_23(); }

  private native double[] GetOrigin_24();
  public double[] GetOrigin()
    { return GetOrigin_24(); }

  private native void SetOrigin_25(double id0,double id1,double id2);
  public void SetOrigin(double id0,double id1,double id2)
    { SetOrigin_25(id0,id1,id2); }

  public vtkGeoCamera() { super(); }

  public vtkGeoCamera(long id) { super(id); }
  public native long   VTKInit();

}
